==> endeavour_2.3.2.orig.tar.gz: endeavour-2.3.2/endeavour2/ziptool.front/config.h <==
/*
        Endeavour IOMega Jaz/Zip Front End Compile Time Configuration
 */

#ifndef CONFIG_ZIP_H
#define CONFIG_ZIP_H

#include "../config.h"


/*
 *      Program name and version:
 */
#ifdef PROG_NAME
# undef PROG_NAME
#endif

#define PROG_NAME	"JAZ/ZIP Tool"



/*
 *	Standard output help message:
 */
#ifdef PROG_HELP_MESG
# undef PROG_HELP_MESG
#endif

#ifdef PROG_LANGUAGE_ENGLISH
#define PROG_HELP_MESG  "\
Usage: ziptool.front [device] [options] [GUI_options]\n\
\n\
    [device] specifies the device to select at startup.\n\
\n\
    [options] can be any of the following:\n\
\n\
        --help                  Prints (this) help screen and exits.\n\
        --version               Prints version information and exits.\n\
\n\
    [GUI_options] can be any options standard to your GUI, consult\n\
    your GUI's manual for available options.\n\
\n"
#endif
#ifdef PROG_LANGUAGE_SPANISH
#define PROG_HELP_MESG	"\
El uso: zip.front [device] [options] [GUI_options]\n\
\n\
    [device] especifica el artefacto para escoger en inicio.\n\
\n\
    [options] puede ser cualquiera de lo Siguiente:\n\
\n\
        --help                  Pantalla de ayuda de Impresiones (esto) de ayuda y salidas.\n\
        --version               Versin Imprime informacin de versin y salidas.\n\
\n\
    [GUI_options] puede ser cualquier estndar de las opcin a su GUI,\n\
    consulta su manual de GUI para opciones disponibles.\n\
\n"
#endif
#ifdef PROG_LANGUAGE_FRENCH
#define PROG_HELP_MESG  "\
L'usage: zip.front [device] [options] [GUI_options]\n\
\n\
    [device] spcifie l'appareil pour choisir au dmarrage.\n\
\n\
    [options] peut tre n'importe quel du suivre:\n\
\n\
        --help                  Caractres (ceci) aide cran et sorties.\n\
        --version               Caractres information de version et sorties.\n\
\n\
    [GUI_options] peut tre n'importe quelle norme d'options  votre\n\
    GUI, consulter le manuel de votre GUI pour les options disponibles.\n\
\n"
#endif



#endif	/* CONFIG_ZIP_H */

==> endeavour_2.5.2.orig.tar.gz: endeavour-2.5.2/endeavour2/ziptool.front/config.h <==
/*
	Endeavour IOMega Jaz/Zip Front End Compile Time Configuration
 */

#ifndef CONFIG_ZIP_H
#define CONFIG_ZIP_H

#include "../config.h"


/*
 *      Program name and version:
 */
#ifdef PROG_NAME
# undef PROG_NAME
#endif
#define PROG_NAME	"ZipTool"

#ifdef PROG_NAME_FULL
# undef PROG_NAME_FULL
#endif
#define PROG_NAME_FULL	"ZipTool"


/*
 *	Standard output help message:
 */
#ifdef PROG_HELP_MESG
# undef PROG_HELP_MESG
#endif

#ifdef PROG_LANGUAGE_ENGLISH
#define PROG_HELP_MESG  "\
Usage: ziptool.front [device] [options] [GUI_options]\n\
\n\
    [device] specifies the device to select at startup.\n\
\n\
    [options] can be any of the following:\n\
\n\
	--help                  Prints (this) help screen and exits.\n\
	--version               Prints version information and exits.\n\
\n\
    [GUI_options] can be any options standard to your GUI, consult\n\
    your GUI's manual for available options.\n\
\n"
#endif
#ifdef PROG_LANGUAGE_SPANISH
#define PROG_HELP_MESG	"\
El uso: zip.front [device] [options] [GUI_options]\n\
\n\
    [device] especifica el artefacto para escoger en inicio.\n\
\n\
    [options] puede ser cualquiera de lo Siguiente:\n\
\n\
	--help                  Pantalla de ayuda de Impresiones (esto) de ayuda y salidas.\n\
	--version               Versin Imprime informacin de versin y salidas.\n\
\n\
    [GUI_options] puede ser cualquier estndar de las opcin a su GUI,\n\
    consulta su manual de GUI para opciones disponibles.\n\
\n"
#endif
#ifdef PROG_LANGUAGE_FRENCH
#define PROG_HELP_MESG  "\
L'usage: zip.front [device] [options] [GUI_options]\n\
\n\
    [device] spcifie l'appareil pour choisir au dmarrage.\n\
\n\
    [options] peut tre n'importe quel du suivre:\n\
\n\
	--help                  Caractres (ceci) aide cran et sorties.\n\
	--version               Caractres information de version et sorties.\n\
\n\
    [GUI_options] peut tre n'importe quelle norme d'options  votre\n\
    GUI, consulter le manuel de votre GUI pour les options disponibles.\n\
\n"
#endif


/*
 *	ZipTool programs:
 *
 *	Do not specify full path in order to allow automatic locating
 *	by checking locations specified in the PATH environment.
 */
#define ZIPTOOL_PROG		"ziptool"


#endif	/* CONFIG_ZIP_H */
